@@ -45,4 +45,4 @@ def ditto(dataset, batch_size, num_nodes, model, objective, optimizer, global_ro
         # server.distribute(nodes, list(range(num_nodes)))
 
     # log
-    log(os.path.basename(__file__)[:-3], nodes, server)
\ No newline at end of file
+    log(os.path.basename(__file__)[:-3] + '_' + str(dataset) +'_' + split['split_method'] +'_' + str(split['split_para']) , nodes, server)
\ No newline at end of file
